package com.redxun.knowledge.common;

import com.redxun.common.model.JPaasUser;
import com.redxun.common.tool.StringUtils;
import com.redxun.common.utils.ExceptionUtil;
import com.redxun.common.utils.SysUserUtil;
import com.redxun.dto.user.OsUserDto;
import com.redxun.feign.org.OrgClient;
import com.redxun.feign.org.UserClient;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 文件名: UserService
 * 作者: Zizg
 * 时间: 2022/11/29
 * 描述:
 * 修改人:
 * 修改时间:
 * 修改内容:
 */
@Component
@Slf4j
public class UserService {

    @Autowired
    private UserClient userClient;

    @Autowired
    private OrgClient orgClient;

    /**
     * 获取当前系统登录用户id
     *
     * @return
     */
    public String queryLoginUser() {
        String loginUserId = null;
        try {
            JPaasUser jPaasUser = SysUserUtil.getLoginUser();
            if (jPaasUser == null) {
                return null;
            }
            loginUserId = jPaasUser.getUserId();
        } catch (IOException e) {
            log.error(ExceptionUtil.getExceptionMessage(e));
        }

        return loginUserId;
    }

    /**
     * 获取当前系统登录用户姓名
     *
     * @return
     */
    public String queryLoginFullName() {
        String userId = queryLoginUser();
        String fullName = userClient.getUserById(userId).getFullName();
        return fullName;
    }

    /**
     * 获取当前系统登录用户姓名编号
     *
     * @return
     */
    public String queryLoginUsername() {
        String userId = queryLoginUser();
        String username = userClient.findByUserId(userId).getUserNo();
        return username;
    }

    /**
     * 获取当前系统登录用户部门id
     *
     * @return
     */
    public String queryLoginUserDeptId() {
        String userId = queryLoginUser();
        String deptId = userClient.findByUserId(userId).getDeptId();
        return deptId;
    }

    /**
     * 根据用户Id查询性别和头像
     *
     */
    public Map<String, Object> querySexAndPhoto(String userId){
        Map<String, Object> map = new HashMap<>();
        String sex = userClient.findByUserId(userId).getSex();
        String photo = userClient.findByUserId(userId).getPhoto();
        map.put("sex",sex);
        map.put("photo",photo);
        return map;
    }

    /**
     * 根据用户ID查询用户对象
     *
     * @param userId 用户ID
     * @return
     */
    public JPaasUser queryUser(String userId) {
        if (StringUtils.isEmpty(userId)) {
            return null;
        }
        return userClient.getUserById(userId);
    }

    /**
     * 根据用户ID查询用户对象
     *
     * @param userId 用户ID
     * @return
     */
    public OsUserDto queryOsUserDto(String userId) {
        if (StringUtils.isEmpty(userId)) {
            return null;
        }
        return userClient.findByUserId(userId);
    }

    /**
     * 根据用户姓名(工号)查询用户对象
     *
     * @param username 用户姓名(工号)
     * @return
     */
    public JPaasUser queryByUsername(String username){
        if (StringUtils.isEmpty(username)) {
            return null;
        }
        return userClient.findByUsername(username);
    }

    /**
     * 根据部门id查询全部员工信息
     * @param deptId
     * @return
     */
    public List<OsUserDto> findUserListByDeptId(String deptId){
        List<OsUserDto> osUserDtoList = orgClient.getByGroupId(deptId);
        return osUserDtoList;
    }


}
